//------------------------------------------------------------------------
//
// OpenDCC - DCCsniffer
//
// Copyright (c) 2008 Kufer
//
// This source file is subject of the GNU general public license 2,
// that is available at the world-wide-web at
// http://www.gnu.org/licenses/gpl.txt
// 
//------------------------------------------------------------------------
//
// file:      external_trig.c
// author:    Wolfgang Kufer (kw)
// contact:   kufer@gmx.de
// webpage:   http://www.opendcc.de
// history:   2007-05-15 V0.1 kw:started
// 
//------------------------------------------------------------------------
//
// purpose:   flexible general purpose decoder for dcc
//            here: event handler for trigger input
//
// content:   A DCC-Decoder for ATmega162 and other AVR
//
//
//------------------------------------------------------------------------

#include <stdlib.h>
#include <stdbool.h>
#include <inttypes.h>
#include <avr/pgmspace.h>        // put var to program memory
#include <avr/io.h>
#include <avr/eeprom.h>
#include <avr/interrupt.h>
#include <string.h>

#include "config.h"             // uses timerval

#include "hardware.h"
#include "TimerPWM.h"


#define SIMULATION  0               // 0: real application
                                    // 1: test init routine
                                    // 2: test timing engine
                                    // 3: test action
#if (SIMULATION != 0)
   #warning SIMULATION is on!
#endif


//---------------------------------------------------------------------
// Timing Definitions:
// (all values given in us)

//------------------------------------------------------------------------------
// internal, but static:
//
// 
#ifndef TRIGGER
 #define TRIGGER        0      // in
 #define TRIGGER_PORT   PINC   // This is the port where we read bits
 #warning TRIGGER not set - default is PINC, Bit 0
#endif


unsigned char trigger_state;                // static - save the previous state of keys.

signed char last_trig_event;              

//------------------------------------------------------------------------------
// code:

void init_trigger(void)
  {
    last_trig_event = systick_1ms;                    // remember time 
  }


unsigned char trigger_poll(void)
  {
    if ((char)(systick_1ms - last_trig_event) < 3)  return(0xFF);   // block reactivation before 3ms

    last_trig_event++;

    if (trigger_state)
      {
        if (TRIGGER_PORT & (1 << TRIGGER))
          {
            // we got a high - Optocoupler is inactive
            trigger_state = FALSE;
            last_trig_event = systick_1ms; 
            return(0);
          }
      }
    else
      {
        if (!(TRIGGER_PORT & (1 << TRIGGER)))
          {
            // we got a low - Optocoupler is active
            trigger_state = TRUE;
            last_trig_event = systick_1ms; 
            return(1);
          }
      }
    return(0xFF);
  }





